#
# spec file for package maven-reporting-api
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           maven-reporting-api
Version:        4.0.0
Release:        1.3
Summary:        API to manage report generation
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://maven.apache.org/shared/maven-reporting-api
Source0:        %{name}-%{version}.tar.xz
Source1:        http://www.apache.org/licenses/LICENSE-2.0.txt
Source2:        %{name}-build.xml
BuildRequires:  ant
BuildRequires:  fdupes
BuildRequires:  javapackages-local >= 6
BuildRequires:  maven-doxia-sink-api >= 2.0
BuildArch:      noarch

%description
API to manage report generation. Maven-reporting-api is included in Maven 2.x
core distribution, but moved to shared components to achieve report decoupling
from Maven 3 core.

This is a replacement package for maven-shared-reporting-api

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Libraries/Java

%description javadoc
API documentation for %{name}.

%prep
%setup -q
cp %{SOURCE1} LICENSE.txt
cp %{SOURCE2} build.xml

%build
mkdir -p lib
build-jar-repository -s lib \
    maven-doxia/doxia-sink-api
ant jar javadoc

%install
# jar
install -dm 0755 %{buildroot}%{_javadir}/%{name}
install -pm 0644 target/%{name}-%{version}.jar %{buildroot}%{_javadir}/%{name}/%{name}.jar
# pom
install -dm 0755 %{buildroot}%{_mavenpomdir}/%{name}
%{mvn_install_pom} pom.xml %{buildroot}%{_mavenpomdir}/%{name}/%{name}.pom
%add_maven_depmap %{name}/%{name}.pom %{name}/%{name}.jar -a  org.apache.maven.shared:maven-reporting-api
# javadoc
install -dm 0755 %{buildroot}%{_javadocdir}/%{name}
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}/
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE.txt

%files javadoc
%{_javadocdir}/%{name}
%license LICENSE.txt

%changelog
* Thu Oct  3 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 4.0.0
  * Improvement
    + MSHARED-193: API change: let MavenReportRenderer#render()
    throw an exception
    + MSHARED-1032: API change: let MavenReport#canGenerateReport()
    throw an exception
  * Task
    + MSHARED-1159: Require locale to be not null
    + MSHARED-1231: Remove unused default-report.xml file
    + MSHARED-1326: Improve MavenReport interface and
    AbstractMavenReport class API
- Fetch sources by source service from Github
* Sun Sep 24 2023 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 3.1.1
  * Task:
    + MSHARED-1118 - Restore binary compat for MavenReport
    (partially revert MSHARED-1024)
* Sun Mar 20 2022 Fridrich Strba <fstrba@suse.com>
- Build with source and target levels 8
* Fri Mar 11 2022 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 3.1.0
  * Improvements:
    + [MSHARED-812] – Require Java 7
    + [MSHARED-879] – make build Reproducible
  * Task:
    + [MSHARED-1024] – Replace deprecated code
  * Dependency upgrade:
    + [MSHARED-844] – Upgrade to Doxia 1.11.1
  * needed for a new maven-javadoc-plugin
* Thu Mar 28 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of maven-reporting-api 3.0
- Generate and customize ant build.xml file
